testutil

package
v0.2.40 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package testutil re-exports protokit/testutil types with MCP-specific finder helpers. All proto descriptor building is delegated to protokit.

Index

Constants

This section is empty.

Variables

CreatePlugin creates a protogen.Plugin from a ProtoSet.

Functions

func FindMessage

func FindMessage(t *testing.T, plugin *protogen.Plugin, name string) protoreflect.MessageDescriptor

FindMessage finds a message descriptor by short name in a plugin's files.

func FindService

func FindService(t *testing.T, plugin *protogen.Plugin, name string) *protogen.Service

FindService finds a service by short name in a plugin's files.

func FindServiceFile added in v0.2.20

func FindServiceFile(t *testing.T, plugin *protogen.Plugin, name string) (*protogen.Service, *protogen.File)

FindServiceFile finds a service by short name and returns both the service and the file it belongs to.

Types

type Enum

type Enum = testutil.TestEnum

Re-export protokit types so callers don't need a double import.

type EnumValue

type EnumValue = testutil.TestEnumValue

Re-export protokit types so callers don't need a double import.

type Field

type Field = testutil.TestField

Re-export protokit types so callers don't need a double import.

type File

type File = testutil.TestFile

Re-export protokit types so callers don't need a double import.

type Message

type Message = testutil.TestMessage

Re-export protokit types so callers don't need a double import.

type Method

type Method = testutil.TestMethod

Re-export protokit types so callers don't need a double import.

type ProtoSet

type ProtoSet = testutil.TestProtoSet

Re-export protokit types so callers don't need a double import.

type Service

type Service = testutil.TestService

Re-export protokit types so callers don't need a double import.

Jump to