Documentation
¶
Overview ¶
Package testutil re-exports protokit/testutil types with MCP-specific finder helpers. All proto descriptor building is delegated to protokit.
Index ¶
- Variables
- func FindMessage(t *testing.T, plugin *protogen.Plugin, name string) protoreflect.MessageDescriptor
- func FindService(t *testing.T, plugin *protogen.Plugin, name string) *protogen.Service
- func FindServiceFile(t *testing.T, plugin *protogen.Plugin, name string) (*protogen.Service, *protogen.File)
- type Enum
- type EnumValue
- type Field
- type File
- type Message
- type Method
- type ProtoSet
- type Service
Constants ¶
This section is empty.
Variables ¶
var CreatePlugin = testutil.CreateTestPlugin
CreatePlugin creates a protogen.Plugin from a ProtoSet.
Functions ¶
func FindMessage ¶
func FindMessage(t *testing.T, plugin *protogen.Plugin, name string) protoreflect.MessageDescriptor
FindMessage finds a message descriptor by short name in a plugin's files.
func FindService ¶
FindService finds a service by short name in a plugin's files.
Types ¶
type EnumValue ¶
type EnumValue = testutil.TestEnumValue
Re-export protokit types so callers don't need a double import.
type Message ¶
type Message = testutil.TestMessage
Re-export protokit types so callers don't need a double import.
type Method ¶
type Method = testutil.TestMethod
Re-export protokit types so callers don't need a double import.
type ProtoSet ¶
type ProtoSet = testutil.TestProtoSet
Re-export protokit types so callers don't need a double import.
type Service ¶
type Service = testutil.TestService
Re-export protokit types so callers don't need a double import.
Click to show internal directories.
Click to hide internal directories.